@@ -43,10 +43,6 @@ test_that("can accept a separating comma, between the arguments and body", {
   expect_equal(fn(x = 1, ~ NULL), function(x = 1) NULL)
 })
 
-test_that("..() is deprecated", {
-  expect_warning(..(x ~ NULL), "`..\\(\\)` is deprecated")
-})
-
 context("as_fn()")
 
 foo <- function(x) as_fn(x)
